==> nobject-rs-1.0.0.crate: nobject-rs-1.0.0/WORK.md <==
# Obj files
## Vertex data
- [x] geometric vertices (v)  
- [x] texture vertices (vt)  
- [x] vertex normals (vn)  
- [x] parameter space vertices (vp) Free-form curve/surface attributes  

## Curves and Surfaces
- [ ] rational or non-rational forms of curve or surface type: basis matrix, Bezier, B-spline, Cardinal, Taylor (cstype)  
- [ ] degree (deg)  
- [ ] basis matrix (bmat)  
- [ ] step size (step)  

## Elements
- [x] point (p)  
- [x] line (l)  
- [x] face (f)  

## Curves and Surface Elements
- [ ] curve (curv)  
- [ ] 2D curve (curv2)  
- [ ] surface (surf)  

## Free-form curve/surface body statements
- [ ] parameter values (parm)  
- [ ] outer trimming loop (trim)  
- [ ] inner trimming loop (hole)  
- [ ] special curve (scrv)  
- [ ] special point (sp)  
- [ ] end statement (end)  

## Connectivity between free-form surfaces
- [ ] connect (con)  

## Grouping
- [x] group name (g)  
- [x] smoothing group (s)  
- [ ] merging group (mg)  
- [x] object name (o)  

## Display/render attributes
- [x] bevel interpolation (bevel)  
- [x] color interpolation (c_interp)  
- [x] dissolve interpolation (d_interp)  
- [x] level of detail (lod)  
- [x] material name (usemtl)  
- [x] material library (mtllib)  
- [x] shadow casting (shadow_obj)  
- [x] ray tracing (trace_obj)  
- [ ] curve approximation technique (ctech)  
- [ ] surface approximation technique (stech)  

# mtl files
- [ ] new material name (newmtl)  
- [ ] ambient (Ka)  
- [ ] diffuse (Kd)  
- [ ] specular (Ks)  
- [ ] non-transparency (d)  
- [ ] transparency (Tr)  
- [ ] transmission filter (Tf)  
- [ ] shininess (Ns)  
- [ ] illumination model (illum)  
- [ ] ambient map (map_Ka)  
- [ ] diffuse map (map_Kd)  
- [ ] specular map (map_Ks)  
- [ ] shininess map (map_Ns)  
- [ ] non-transparency map (map_d)  
- [ ] texture anti-aliasing (map_aat)  
- [ ] displacement map (disp)  
- [ ] decal map (decal)  
- [ ] bump map (bump)  
- [ ] reflection map (refl)

==> nobject-rs-1.1.1.crate: nobject-rs-1.1.1/WORK.md <==
# Obj files
## Vertex data
- [x] geometric vertices (v)  
- [x] texture vertices (vt)  
- [x] vertex normals (vn)  
- [x] parameter space vertices (vp) Free-form curve/surface attributes  

## Curves and Surfaces
- [ ] rational or non-rational forms of curve or surface type: basis matrix, Bezier, B-spline, Cardinal, Taylor (cstype)  
- [ ] degree (deg)  
- [ ] basis matrix (bmat)  
- [ ] step size (step)  

## Elements
- [x] point (p)  
- [x] line (l)  
- [x] face (f)  

## Curves and Surface Elements
- [ ] curve (curv)  
- [ ] 2D curve (curv2)  
- [ ] surface (surf)  

## Free-form curve/surface body statements
- [ ] parameter values (parm)  
- [ ] outer trimming loop (trim)  
- [ ] inner trimming loop (hole)  
- [ ] special curve (scrv)  
- [ ] special point (sp)  
- [ ] end statement (end)  

## Connectivity between free-form surfaces
- [ ] connect (con)  

## Grouping
- [x] group name (g)  
- [x] smoothing group (s)  
- [ ] merging group (mg)  
- [x] object name (o)  

## Display/render attributes
- [x] bevel interpolation (bevel)  
- [x] color interpolation (c_interp)  
- [x] dissolve interpolation (d_interp)  
- [x] level of detail (lod)  
- [x] material name (usemtl)  
- [x] material library (mtllib)  
- [x] shadow casting (shadow_obj)  
- [x] ray tracing (trace_obj)  
- [ ] curve approximation technique (ctech)  
- [ ] surface approximation technique (stech)  

# mtl files
- [x] new material name (newmtl)  
- [x] ambient (Ka)  
- [x] diffuse (Kd)  
- [x] specular (Ks)  
- [x] non-transparency (d)  
- [x] transparency (Tr)  
- [x] transmission filter (Tf)  
- [x] shininess (Ns)  
- [x] illumination model (illum)  
- [x] ambient map (map_Ka)  
- [x] diffuse map (map_Kd)  
- [x] specular map (map_Ks)  
- [x] shininess map (map_Ns)  
- [x] non-transparency map (map_d)  
- [x] texture anti-aliasing (map_aat)  
- [x] displacement map (disp)  
- [x] decal map (decal)  
- [x] bump map (bump)  
- [x] reflection map (refl)
